==> hooks-18.4.0.tgz: package/useResize.js <==
import { isUndefined } from 'lodash';
import { useEffect, useRef } from 'react';
import { flushSync } from 'react-dom';
export function useResize(target, cb, disabled = false, skipEmpty = true) {
    const dataRef = useRef({});
    if (disabled) {
        dataRef.current.prevContentRect = undefined;
    }
    useEffect(() => {
        if (target.current && !disabled) {
            const observer = new ResizeObserver((entries, observer) => {
                let entry = entries[0];
                if ('borderBoxSize' in entry) {
                    if (!isUndefined(dataRef.current.prevContentRect) &&
                        !(skipEmpty && entry.borderBoxSize[0].blockSize === 0 && entry.borderBoxSize[0].inlineSize === 0) &&
                        (dataRef.current.prevContentRect.width !== entry.borderBoxSize[0].inlineSize ||
                            dataRef.current.prevContentRect.height !== entry.borderBoxSize[0].blockSize)) {
                        flushSync(() => cb === null || cb === void 0 ? void 0 : cb(entries, observer));
                    }
                    dataRef.current.prevContentRect = { width: entry.borderBoxSize[0].inlineSize, height: entry.borderBoxSize[0].blockSize };
                }
                else {
                    entry = entries[0];
                    if (!isUndefined(dataRef.current.prevContentRect) &&
                        !(skipEmpty && entry.contentRect.width === 0 && entry.contentRect.height === 0) &&
                        (dataRef.current.prevContentRect.width !== entry.contentRect.width ||
                            dataRef.current.prevContentRect.height !== entry.contentRect.height)) {
                        flushSync(() => cb === null || cb === void 0 ? void 0 : cb(entries, observer));
                    }
                    dataRef.current.prevContentRect = { width: entry.contentRect.width, height: entry.contentRect.height };
                }
            });
            observer.observe(target.current);
            return () => {
                observer.disconnect();
            };
        }
    });
}

==> hooks-18.5.13.tgz: package/useResize.js <==
import { isUndefined } from 'lodash';
import { useEffect, useRef } from 'react';
import { flushSync } from 'react-dom';
let checkResize = (cb1, cb2, entry) => {
    if ('borderBoxSize' in entry) {
        checkResize = (cb1) => {
            cb1();
        };
    }
    else {
        checkResize = (cb1, cb2) => {
            cb2();
        };
    }
};
export function useResize(target, cb, disabled = false, skipEmpty = true) {
    const dataRef = useRef({});
    if (disabled) {
        dataRef.current.prevContentRect = undefined;
    }
    useEffect(() => {
        if (target.current && !disabled) {
            const observer = new ResizeObserver((entries, observer) => {
                const entry = entries[0];
                checkResize(() => {
                    if (!isUndefined(dataRef.current.prevContentRect) &&
                        !(skipEmpty && entry.borderBoxSize[0].blockSize === 0 && entry.borderBoxSize[0].inlineSize === 0) &&
                        (dataRef.current.prevContentRect.width !== entry.borderBoxSize[0].inlineSize ||
                            dataRef.current.prevContentRect.height !== entry.borderBoxSize[0].blockSize)) {
                        flushSync(() => cb === null || cb === void 0 ? void 0 : cb(entries, observer));
                    }
                    dataRef.current.prevContentRect = { width: entry.borderBoxSize[0].inlineSize, height: entry.borderBoxSize[0].blockSize };
                }, () => {
                    if (!isUndefined(dataRef.current.prevContentRect) &&
                        !(skipEmpty && entry.contentRect.width === 0 && entry.contentRect.height === 0) &&
                        (dataRef.current.prevContentRect.width !== entry.contentRect.width ||
                            dataRef.current.prevContentRect.height !== entry.contentRect.height)) {
                        flushSync(() => cb === null || cb === void 0 ? void 0 : cb(entries, observer));
                    }
                    dataRef.current.prevContentRect = { width: entry.contentRect.width, height: entry.contentRect.height };
                }, entry);
            });
            observer.observe(target.current);
            return () => {
                observer.disconnect();
            };
        }
    });
}
